@@ -10,11 +10,6 @@
 #define WRAPPER_SAFE() SB_SAFE_OPEN_CHAR(pathname, mode)
 #define WRAPPER_RET_TYPE FILE *
 #define WRAPPER_RET_DEFAULT NULL
-
-#ifdef SB64
-# define WRAPPER_PRE_CHECKS() sb_fopen64_pre_check(STRING_NAME, pathname, mode)
-#else
-# define WRAPPER_PRE_CHECKS() sb_fopen_pre_check(STRING_NAME, pathname, mode)
-#endif
+#define WRAPPER_PRE_CHECKS() sb_fopen_pre_check(STRING_NAME, pathname, mode)
 
 #include "__wrapper_simple.c"
