@@ -35,8 +35,8 @@ static void sbio_init(void)
  */
 static void sb_vefunc(const char *prog, const char *color, const char *format, va_list args)
 {
+	bool opened;
 	int fd;
-	FILE *fp;
 
 	if (likely(sbio_message_path))
 		fd = sbio_open(sbio_message_path, O_WRONLY|O_APPEND|O_CLOEXEC, 0);
@@ -44,15 +44,16 @@ static void sb_vefunc(const char *prog, const char *color, const char *format, v
 		fd = -1;
 	if (fd == -1)
 		fd = sbio_open(sbio_fallback_path, O_WRONLY|O_CLOEXEC, 0);
-	fp = fd == -1 ? NULL : fdopen(fd, "ae");
-	if (!fp)
-		fp = stderr;
+	opened = (fd != -1);
+	if (fd == -1)
+		fd = fileno(stderr);
 
-	sb_fprintf(fp, " %s*%s ", color, COLOR_NORMAL);
-	sb_vfprintf(fp, format, args);
+	if (color)
+		sb_fdprintf(fd, " %s*%s ", color, COLOR_NORMAL);
+	sb_vfdprintf(fd, format, args);
 
-	if (fp != stderr)
-		fclose(fp);
+	if (opened)
+		close(fd);
 }
 
 void sb_einfo(const char *format, ...)
@@ -98,6 +99,17 @@ void sb_eqawarn(const char *format, ...)
 	va_end(args);
 }
 
+/* This is a bit of a hack to expose the same file logic to generic printers.
+ * Probably want to revisit sb_vefunc and move the guts there to a new func.
+ */
+void sb_eraw(const char *format, ...)
+{
+	va_list args;
+	va_start(args, format);
+	sb_vefunc(NULL, NULL, format, args);
+	va_end(args);
+}
+
 void sb_dump_backtrace(void)
 {
 #ifdef HAVE_BACKTRACE
